#region Copyright Syncfusion Inc. 2001 - 2005
//
//  Copyright Syncfusion Inc. 2001 - 2005. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

using System;
using System.ComponentModel;
using System.Globalization;
using System.Runtime.Serialization;
using System.Windows.Forms;
using System.Diagnostics;
using System.Collections;

using Syncfusion.Windows.Forms.Diagram;

namespace ControlsGalore
{	
	/// <summary>
	/// CustomListSymbol class that exposes a serializable ListBox hosted by its child ControlNode.
	/// </summary>
	[
	Serializable()
	]
	public class CustomListSymbol : Symbol
	{
		private ControlNode childNode;			

		/// <summary>
		/// Default constructor.
		/// </summary>
		public CustomListSymbol()
		{			
		}

		/// <summary>
		/// Copy constructor.
		/// </summary>
		/// <param name="src"></param>
		public CustomListSymbol(CustomListSymbol src) : base(src)
		{
		}

		/// <summary>
		/// Serialization constructor for the CustomList class.
		/// </summary>
		/// <param name="info">Serialization state information</param>
		/// <param name="context">Streaming context information</param>
		protected CustomListSymbol(SerializationInfo info, StreamingContext context) : base(info, context)
		{
			
		}

		/// <summary>
		/// Creates a new object that is a copy of the current instance.
		/// </summary>
		/// <returns>Copy of the object this method is invoked against</returns>
		public override object Clone()
		{
			return new CustomListSymbol(this);
		}

		[
		Category("Child Control"),
		Description("The child control hosted by the ControlNode")
		]
		public Control ListBoxControl
		{
			get
			{
				if(this.childNode == null)
				{
					foreach(INode node in this.children)
					{
						if(node is ControlNode)
						{
							this.childNode = node as ControlNode;
							break;
						}
					}
				}
				if(childNode != null)
					return childNode.Control;
				return null;
			}
		}
	}


	/// <summary>
	/// Serializable ListBox control used by the CustomListSymbol.
	/// </summary>
	[Serializable()]
	public class CustomListBox : System.Windows.Forms.ListBox, ISerializable
	{
		public CustomListBox()
		{
			this.IntegralHeight = false;
			string[] itemsarray = new string[]{"ListBox in a ControlNode", "Use PropertyEditor to add/remove items"};
			this.Items.AddRange(itemsarray);		
		}

		protected CustomListBox(SerializationInfo info, StreamingContext context)
		{
			this.IntegralHeight = false;
			string[] itemsarray = (string[])info.GetValue("listboxitems", typeof(string[]));
			this.Items.AddRange(itemsarray);
		}

		void ISerializable.GetObjectData(SerializationInfo info, StreamingContext context)
		{
			string[] itemsarray = new string[this.Items.Count];
			this.Items.CopyTo(itemsarray, 0);
			info.AddValue("listboxitems", itemsarray);
		}
	}
}